@@ -4,7 +4,7 @@ def q1(qn=0):
     from IPython.display import display, Image
     import os
     if not qn:
-        print(sorted(contents('qu1')))
+        print(sorted(contents('pm20_5')))
         with path(
                 'qu1',
                 'q1_task1.png'
